@@ -2,43 +2,32 @@ use strict;
 use warnings;
 
 package W3C::XMLSchema::ComplexType;
-BEGIN {
-  $W3C::XMLSchema::ComplexType::VERSION = '0.0.2';
+{
+  $W3C::XMLSchema::ComplexType::VERSION = '0.0.3';
 }
-use Moose;
-with 'XML::Rabbit::Node';
+use XML::Rabbit;
 
 # ABSTRACT: XMLSchema ComplexType Definition
 
 
-has 'name' => (
-    traits      => ['XPathValue'],
-    xpath_query => './@name',
-);
+has_xpath_value 'name' => './@name';
 
 
-has 'mixed' => (
-    traits      => ['XPathValue'],
-    xpath_query => './@mixed',
-);
+has_xpath_value 'mixed' => './@mixed';
 
 
-has 'items' => (
-    traits      => ['XPathObjectList'],
-    xpath_query => './*',
-    isa_map     => {
+has_xpath_object_list 'items' => './*',
+    {
         'xsd:group'          => 'W3C::XMLSchema::Group',
         'xsd:attributeGroup' => 'W3C::XMLSchema::AttributeGroup',
     },
-);
-
-no Moose;
-__PACKAGE__->meta->make_immutable();
+;
 
+finalize_class();
 1;
 
 
-__END__
+
 =pod
 
 =encoding utf-8
@@ -49,7 +38,7 @@ W3C::XMLSchema::ComplexType - XMLSchema ComplexType Definition
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 DESCRIPTION
 
@@ -75,14 +64,17 @@ composed of simple types, either elements or attributes.
 
 =head1 AUTHOR
 
-  Robin Smidsrød <robin@smidsrod.no>
+Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Robin Smidsrød.
+This software is copyright (c) 2011 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
