@@ -2,51 +2,33 @@ use strict;
 use warnings;
 
 package W3C::XMLSchema::Element;
-BEGIN {
-  $W3C::XMLSchema::Element::VERSION = '0.0.2';
+{
+  $W3C::XMLSchema::Element::VERSION = '0.0.3';
 }
-use Moose;
-with 'XML::Rabbit::Node';
+use XML::Rabbit;
 
 # ABSTRACT: XMLSchema Element Definition
 
 
-has 'name' => (
-    traits      => [qw/XPathValue/],
-    xpath_query => './@name',
-);
+has_xpath_value 'name' => './@name';
 
 
-has 'type' => (
-    traits      => [qw/XPathValue/],
-    xpath_query => './@type',
-);
+has_xpath_value 'type' => './@type';
 
 
-has 'ref' => (
-    traits      => [qw/XPathValue/],
-    xpath_query => './@ref',
-);
+has_xpath_value 'ref' => './@ref';
 
 
-has 'minOccurs' => (
-    traits      => [qw/XPathValue/],
-    xpath_query => './@minOccurs',
-);
+has_xpath_value 'minOccurs' => './@minOccurs';
 
 
-has 'maxOccurs' => (
-    traits      => [qw/XPathValue/],
-    xpath_query => './@maxOccurs',
-);
-
-no Moose;
-__PACKAGE__->meta->make_immutable();
+has_xpath_value 'maxOccurs' => './@maxOccurs';
 
+finalize_class();
 1;
 
 
-__END__
+
 =pod
 
 =encoding utf-8
@@ -57,7 +39,7 @@ W3C::XMLSchema::Element - XMLSchema Element Definition
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 DESCRIPTION
 
@@ -89,14 +71,17 @@ Maximum amount of occurences. 'unbounded' means no upper limit.
 
 =head1 AUTHOR
 
-  Robin Smidsrød <robin@smidsrod.no>
+Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Robin Smidsrød.
+This software is copyright (c) 2011 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
