@@ -2,40 +2,27 @@ use strict;
 use warnings;
 
 package W3C::XMLSchema::Group;
-BEGIN {
-  $W3C::XMLSchema::Group::VERSION = '0.0.2';
+{
+  $W3C::XMLSchema::Group::VERSION = '0.0.3';
 }
-use Moose;
-with 'XML::Rabbit::Node';
+use XML::Rabbit;
 
 # ABSTRACT: XMLSchema Group Definition
 
 
-has 'name' => (
-    traits      => ['XPathValue'],
-    xpath_query => './@name',
-);
+has_xpath_value 'name' => './@name';
 
 
-has 'ref' => (
-    traits      => ['XPathValue'],
-    xpath_query => './@ref',
-);
+has_xpath_value 'ref' => './@ref';
 
 
-has 'sequence' => (
-    isa         => 'W3C::XMLSchema::Sequence',
-    traits      => ['XPathObject'],
-    xpath_query => './xsd:sequence',
-);
-
-no Moose;
-__PACKAGE__->meta->make_immutable();
+has_xpath_object 'sequence' => './xsd:sequence' => 'W3C::XMLSchema::Sequence';
 
+finalize_class();
 1;
 
 
-__END__
+
 =pod
 
 =encoding utf-8
@@ -46,7 +33,7 @@ W3C::XMLSchema::Group - XMLSchema Group Definition
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 DESCRIPTION
 
@@ -70,14 +57,17 @@ The sequence this group requires. Instance of L<W3C::XMLSchema::Sequence>.
 
 =head1 AUTHOR
 
-  Robin Smidsrød <robin@smidsrod.no>
+Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Robin Smidsrød.
+This software is copyright (c) 2011 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
