@@ -2,31 +2,26 @@ use strict;
 use warnings;
 
 package W3C::XMLSchema::Sequence;
-BEGIN {
-  $W3C::XMLSchema::Sequence::VERSION = '0.0.2';
+{
+  $W3C::XMLSchema::Sequence::VERSION = '0.0.3';
 }
-use Moose;
-with 'XML::Rabbit::Node';
+use XML::Rabbit;
 
 # ABSTRACT: XMLSchema Sequence Definition
 
 
-has 'items' => (
-    traits      => ['XPathObjectList'],
-    xpath_query => './*',
-    isa_map     => {
+has_xpath_object_list 'items' => './*',
+    {
         'xsd:group'   => 'W3C::XMLSchema::Group',
         'xsd:element' => 'W3C::XMLSchema::Element',
     },
-);
-
-no Moose;
-__PACKAGE__->meta->make_immutable();
+;
 
+finalize_class();
 1;
 
 
-__END__
+
 =pod
 
 =encoding utf-8
@@ -37,7 +32,7 @@ W3C::XMLSchema::Sequence - XMLSchema Sequence Definition
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 DESCRIPTION
 
@@ -54,14 +49,17 @@ L<W3C::XMLSchema::Element>.
 
 =head1 AUTHOR
 
-  Robin Smidsrød <robin@smidsrod.no>
+Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Robin Smidsrød.
+This software is copyright (c) 2011 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
